==> haskell-expiring-cache-map-0.0.6.1-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: expiring-cache-map
version: 0.0.6.1
id: expiring-cache-map-0.0.6.1-BXK0UHCkE2W5cX0GoVWbCp
key: expiring-cache-map-0.0.6.1-BXK0UHCkE2W5cX0GoVWbCp
license: BSD-3-Clause
copyright: (c) 2014 Edward L. Blake
maintainer: edwardlblake@gmail.com
author: Edward L. Blake
homepage: https://github.com/elblake/expiring-cache-map
synopsis: General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.
category: Caching
abi: 4de93c6c59015547eb8aed956746e0d3
exposed: True
exposed-modules:
    Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/expiring-cache-map-0.0.6.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/expiring-cache-map-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/expiring-cache-map-0.0.6.1
hs-libraries: HSexpiring-cache-map-0.0.6.1-BXK0UHCkE2W5cX0GoVWbCp
depends:
    base-4.12.0.0 containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    unordered-containers-0.2.10.0-DuDkJMfSb9t61flNcUovL1
haddock-interfaces: /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock
haddock-html: /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-expiring-cache-map-0.0.6.1-43-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: expiring-cache-map
version: 0.0.6.1
id: expiring-cache-map-0.0.6.1-JYL73GoJ9NU6Pu813AKKkl
key: expiring-cache-map-0.0.6.1-JYL73GoJ9NU6Pu813AKKkl
license: BSD-3-Clause
copyright: (c) 2014 Edward L. Blake
maintainer: edwardlblake@gmail.com
author: Edward L. Blake
homepage: https://github.com/elblake/expiring-cache-map
synopsis: General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.
category: Caching
abi: feb9b76cd3fa169fa689b404867d816e
exposed: True
exposed-modules:
    Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/expiring-cache-map-0.0.6.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/expiring-cache-map-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/expiring-cache-map-0.0.6.1
hs-libraries: HSexpiring-cache-map-0.0.6.1-JYL73GoJ9NU6Pu813AKKkl
depends:
    base-4.12.0.0 containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
haddock-interfaces: /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock
haddock-html: /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
